@@ -4,16 +4,16 @@
 use std::convert::TryInto;
 use std::ops::{self, Neg};
 
-use anyhow::{anyhow, Context};
+use anyhow::anyhow;
 use bitfield::{BitField, UnvalidatedBitField, Validate};
 use cid::Cid;
 use fil_actors_runtime::runtime::Policy;
 use fil_actors_runtime::{actor_error, ActorDowncast, Array};
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
 use fvm_shared::bigint::bigint_ser;
+use fvm_shared::blockstore::Blockstore;
 use fvm_shared::clock::{ChainEpoch, QuantSpec, NO_QUANTIZATION};
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::tuple::*;
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{SectorSize, StoragePower};
 use num_traits::{Signed, Zero};
@@ -165,9 +165,10 @@ impl Partition {
             .map_err(|e| e.downcast_wrap("failed to load partition queue"))?;
 
         // Reschedule faults
-        let new_faulty_power = queue
-            .reschedule_as_faults(fault_expiration, sectors, sector_size)
-            .map_err(|e| e.downcast_wrap("failed to add faults to partition queue"))?;
+        let new_faulty_power =
+            queue
+                .reschedule_as_faults(fault_expiration, sectors, sector_size)
+                .map_err(|e| e.downcast_wrap("failed to add faults to partition queue"))?;
 
         // Save expiration queue
         self.expirations_epochs = queue.amt.flush()?;
@@ -218,7 +219,7 @@ impl Partition {
         quant: QuantSpec,
     ) -> anyhow::Result<(BitField, PowerPair, PowerPair)> {
         validate_partition_contains_sectors(self, sector_numbers)
-            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT; "failed fault declaration: {}", e))?;
+            .map_err(|e| actor_error!(ErrIllegalArgument; "failed fault declaration: {}", e))?;
 
         let sector_numbers = sector_numbers
             .validate()
@@ -233,9 +234,8 @@ impl Partition {
         new_faults -= &self.faults;
 
         // Add new faults to state.
-        let new_fault_sectors = sectors
-            .load_sector(&new_faults)
-            .map_err(|e| e.wrap("failed to load fault sectors"))?;
+        let new_fault_sectors =
+            sectors.load_sector(&new_faults).map_err(|e| e.wrap("failed to load fault sectors"))?;
 
         let (power_delta, new_faulty_power) = if !new_fault_sectors.is_empty() {
             self.add_faults(
@@ -316,7 +316,7 @@ impl Partition {
     ) -> anyhow::Result<()> {
         // Check that the declared sectors are actually assigned to the partition.
         validate_partition_contains_sectors(self, sector_numbers)
-            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT; "failed fault declaration: {}", e))?;
+            .map_err(|e| actor_error!(ErrIllegalArgument; "failed fault declaration: {}", e))?;
 
         let sector_numbers = sector_numbers
             .validate()
@@ -377,11 +377,7 @@ impl Partition {
         quant: QuantSpec,
     ) -> anyhow::Result<Vec<SectorOnChainInfo>> {
         let sector_numbers = sector_numbers.validate().map_err(|e| {
-            actor_error!(
-                USR_ILLEGAL_ARGUMENT,
-                "failed to validate rescheduled sectors: {}",
-                e
-            )
+            actor_error!(ErrIllegalArgument, "failed to validate rescheduled sectors: {}", e)
         })?;
 
         // Ensure these sectors actually belong to this partition.
@@ -494,30 +490,18 @@ impl Partition {
     ) -> anyhow::Result<ExpirationSet> {
         let live_sectors = self.live_sectors();
         let sector_numbers = sector_numbers.validate().map_err(|e| {
-            actor_error!(
-                USR_ILLEGAL_ARGUMENT,
-                "failed to validate terminating sectors: {}",
-                e
-            )
+            actor_error!(ErrIllegalArgument, "failed to validate terminating sectors: {}", e)
         })?;
 
         if !live_sectors.contains_all(sector_numbers) {
-            return Err(
-                actor_error!(USR_ILLEGAL_ARGUMENT, "can only terminate live sectors").into(),
-            );
+            return Err(actor_error!(ErrIllegalArgument, "can only terminate live sectors").into());
         }
 
         let sector_infos = sectors.load_sector(sector_numbers)?;
         let mut expirations = ExpirationQueue::new(store, &self.expirations_epochs, quant)
             .map_err(|e| e.downcast_wrap("failed to load sector expirations"))?;
         let (mut removed, removed_recovering) = expirations
-            .remove_sectors(
-                policy,
-                &sector_infos,
-                &self.faults,
-                &self.recoveries,
-                sector_size,
-            )
+            .remove_sectors(policy, &sector_infos, &self.faults, &self.recoveries, sector_size)
             .map_err(|e| e.downcast_wrap("failed to remove sector expirations"))?;
 
         self.expirations_epochs = expirations
@@ -585,14 +569,10 @@ impl Partition {
         // and all recoveries retracted.
         // No recoveries may be posted until the deadline is closed.
         if !self.recoveries.is_empty() {
-            return Err(anyhow!(
-                "unexpected recoveries while processing expirations"
-            ));
+            return Err(anyhow!("unexpected recoveries while processing expirations"));
         }
         if !self.recovering_power.is_zero() {
-            return Err(anyhow!(
-                "unexpected recovering power while processing expirations"
-            ));
+            return Err(anyhow!("unexpected recovering power while processing expirations"));
         }
 
         // Nothing expiring now should have already terminated.
@@ -685,7 +665,7 @@ impl Partition {
                 let to_process = if limit < count {
                     let to_process = sectors
                         .slice(0, limit)
-                        .context("expected more sectors in bitfield")?;
+                        .map_err(|e| anyhow!("failed to slice early terminations: {}", e))?;
                     let rest = sectors - &to_process;
                     remaining = Some((rest, epoch));
                     result.sectors_processed += limit;
@@ -704,20 +684,14 @@ impl Partition {
             .map_err(|e| e.downcast_wrap("failed to walk early terminations queue"))?;
 
         // Update early terminations
-        early_terminated_queue
-            .amt
-            .batch_delete(processed, true)
-            .map_err(|e| {
-                e.downcast_wrap("failed to remove entries from early terminations queue")
-            })?;
+        early_terminated_queue.amt.batch_delete(processed, true).map_err(|e| {
+            e.downcast_wrap("failed to remove entries from early terminations queue")
+        })?;
 
         if let Some((remaining_sectors, remaining_epoch)) = remaining.take() {
-            early_terminated_queue
-                .amt
-                .set(remaining_epoch as u64, remaining_sectors)
-                .map_err(|e| {
-                    e.downcast_wrap("failed to update remaining entry early terminations queue")
-                })?;
+            early_terminated_queue.amt.set(remaining_epoch as u64, remaining_sectors).map_err(
+                |e| e.downcast_wrap("failed to update remaining entry early terminations queue"),
+            )?;
         }
 
         // Save early terminations.
@@ -749,26 +723,17 @@ impl Partition {
         skipped: &mut UnvalidatedBitField,
     ) -> anyhow::Result<(PowerPair, PowerPair, PowerPair, bool)> {
         let skipped = skipped.validate().map_err(|e| {
-            actor_error!(
-                USR_ILLEGAL_ARGUMENT,
-                "failed to validate skipped sectors: {}",
-                e
-            )
+            actor_error!(ErrIllegalArgument, "failed to validate skipped sectors: {}", e)
         })?;
 
         if skipped.is_empty() {
-            return Ok((
-                PowerPair::zero(),
-                PowerPair::zero(),
-                PowerPair::zero(),
-                false,
-            ));
+            return Ok((PowerPair::zero(), PowerPair::zero(), PowerPair::zero(), false));
         }
 
         // Check that the declared sectors are actually in the partition.
         if !self.sectors.contains_all(skipped) {
             return Err(actor_error!(
-                USR_ILLEGAL_ARGUMENT,
+                ErrIllegalArgument,
                 "skipped faults contains sectors outside partition"
             )
             .into());
@@ -783,9 +748,8 @@ impl Partition {
 
         // Ignore skipped faults that are already faults or terminated.
         let new_faults = &(&*skipped - &self.terminated) - &self.faults;
-        let new_fault_sectors = sectors
-            .load_sector(&new_faults)
-            .map_err(|e| e.wrap("failed to load sectors"))?;
+        let new_fault_sectors =
+            sectors.load_sector(&new_faults).map_err(|e| e.wrap("failed to load sectors"))?;
 
         // Record new faults
         let (power_delta, new_fault_power) = self
@@ -798,7 +762,7 @@ impl Partition {
                 quant,
             )
             .map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to add skipped faults")
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to add skipped faults")
             })?;
 
         // Remove faulty recoveries
@@ -807,12 +771,7 @@ impl Partition {
         // check invariants
         self.validate_state()?;
 
-        Ok((
-            power_delta,
-            new_fault_power,
-            retracted_recovery_power,
-            !new_fault_sectors.is_empty(),
-        ))
+        Ok((power_delta, new_fault_power, retracted_recovery_power, !new_fault_sectors.is_empty()))
     }
 
     /// Test invariants about the partition power are valid.
@@ -850,9 +809,7 @@ impl Partition {
 
         // Unproven or faulty sectors should not be in terminated
         if self.terminated.contains_any(&merge) {
-            return Err(anyhow!(
-                "Partition left with terminated sectors in multiple states"
-            ));
+            return Err(anyhow!("Partition left with terminated sectors in multiple states"));
         }
 
         merge |= &self.terminated;
@@ -900,10 +857,7 @@ impl ops::Add for &PowerPair {
     type Output = PowerPair;
 
     fn add(self, rhs: Self) -> Self::Output {
-        PowerPair {
-            raw: &self.raw + &rhs.raw,
-            qa: &self.qa + &rhs.qa,
-        }
+        PowerPair { raw: &self.raw + &rhs.raw, qa: &self.qa + &rhs.qa }
     }
 }
 
@@ -917,10 +871,7 @@ impl ops::Sub for &PowerPair {
     type Output = PowerPair;
 
     fn sub(self, rhs: Self) -> Self::Output {
-        PowerPair {
-            raw: &self.raw - &rhs.raw,
-            qa: &self.qa - &rhs.qa,
-        }
+        PowerPair { raw: &self.raw - &rhs.raw, qa: &self.qa - &rhs.qa }
     }
 }
 
@@ -934,10 +885,7 @@ impl ops::Neg for PowerPair {
     type Output = PowerPair;
 
     fn neg(self) -> Self::Output {
-        PowerPair {
-            raw: -self.raw,
-            qa: -self.qa,
-        }
+        PowerPair { raw: -self.raw, qa: -self.qa }
     }
 }
 
