@@ -14,14 +14,14 @@ use fil_actors_runtime::{
     ActorError, Array,
 };
 use fvm_ipld_amt::Error as AmtError;
-use fvm_ipld_blockstore::Blockstore;
-use fvm_ipld_encoding::tuple::{Deserialize_tuple, Serialize_tuple};
-use fvm_ipld_encoding::{serde_bytes, BytesDe, Cbor, CborStore};
 use fvm_ipld_hamt::Error as HamtError;
 use fvm_shared::address::Address;
 use fvm_shared::bigint::bigint_ser;
+use fvm_shared::blockstore::{Blockstore, CborStore};
 use fvm_shared::clock::{ChainEpoch, QuantSpec, EPOCH_UNDEFINED};
 use fvm_shared::econ::TokenAmount;
+use fvm_shared::encoding::tuple::*;
+use fvm_shared::encoding::{serde_bytes, BytesDe, Cbor};
 use fvm_shared::error::ExitCode;
 use fvm_shared::sector::{RegisteredPoStProof, SectorNumber, SectorSize, MAX_SECTOR_NUMBER};
 use fvm_shared::HAMT_BIT_WIDTH;
@@ -37,7 +37,7 @@ use super::{
 };
 
 const PRECOMMIT_EXPIRY_AMT_BITWIDTH: u32 = 6;
-const SECTORS_AMT_BITWIDTH: u32 = 5;
+pub const SECTORS_AMT_BITWIDTH: u32 = 5;
 
 /// Balance of Miner Actor should be greater than or equal to
 /// the sum of PreCommitDeposits and LockedFunds.
@@ -129,11 +129,10 @@ impl State {
         period_start: ChainEpoch,
         deadline_idx: u64,
     ) -> anyhow::Result<Self> {
-        let empty_precommit_map = make_empty_map::<_, ()>(store, HAMT_BIT_WIDTH)
-            .flush()
-            .map_err(|e| {
+        let empty_precommit_map =
+            make_empty_map::<_, ()>(store, HAMT_BIT_WIDTH).flush().map_err(|e| {
                 e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
+                    ExitCode::ErrIllegalState,
                     "failed to construct empty precommit map",
                 )
             })?;
@@ -142,7 +141,7 @@ impl State {
                 .flush()
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         "failed to construct empty precommits array",
                     )
                 })?;
@@ -151,42 +150,27 @@ impl State {
                 .flush()
                 .map_err(|e| {
                     e.downcast_default(
-                        ExitCode::USR_ILLEGAL_STATE,
+                        ExitCode::ErrIllegalState,
                         "failed to construct sectors array",
                     )
                 })?;
-        let empty_bitfield = store
-            .put_cbor(&BitField::new(), Code::Blake2b256)
-            .map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to construct empty bitfield",
-                )
-            })?;
+        let empty_bitfield = store.put_cbor(&BitField::new(), Code::Blake2b256).map_err(|e| {
+            e.downcast_default(ExitCode::ErrIllegalState, "failed to construct empty bitfield")
+        })?;
         let deadline = Deadline::new(store)?;
         let empty_deadline = store.put_cbor(&deadline, Code::Blake2b256).map_err(|e| {
-            e.downcast_default(
-                ExitCode::USR_ILLEGAL_STATE,
-                "failed to construct illegal state",
-            )
+            e.downcast_default(ExitCode::ErrIllegalState, "failed to construct illegal state")
         })?;
 
         let empty_deadlines = store
             .put_cbor(&Deadlines::new(policy, empty_deadline), Code::Blake2b256)
             .map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to construct illegal state",
-                )
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to construct illegal state")
             })?;
 
-        let empty_vesting_funds_cid = store
-            .put_cbor(&VestingFunds::new(), Code::Blake2b256)
-            .map_err(|e| {
-                e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
-                    "failed to construct illegal state",
-                )
+        let empty_vesting_funds_cid =
+            store.put_cbor(&VestingFunds::new(), Code::Blake2b256).map_err(|e| {
+                e.downcast_default(ExitCode::ErrIllegalState, "failed to construct illegal state")
             })?;
 
         Ok(Self {
@@ -215,7 +199,7 @@ impl State {
     pub fn get_info<BS: Blockstore>(&self, store: &BS) -> anyhow::Result<MinerInfo> {
         match store.get_cbor(&self.info) {
             Ok(Some(info)) => Ok(info),
-            Ok(None) => Err(actor_error!(USR_NOT_FOUND, "failed to get miner info").into()),
+            Ok(None) => Err(actor_error!(ErrNotFound, "failed to get miner info").into()),
             Err(e) => Err(e.downcast_wrap("failed to get miner info")),
         }
     }
@@ -241,12 +225,7 @@ impl State {
         policy: &Policy,
         current_epoch: ChainEpoch,
     ) -> DeadlineInfo {
-        new_deadline_info(
-            policy,
-            self.proving_period_start,
-            self.current_deadline,
-            current_epoch,
-        )
+        new_deadline_info(policy, self.proving_period_start, self.current_deadline, current_epoch)
     }
 
     // Returns current proving period start for the current epoch according to the current epoch and constant state offset
@@ -276,13 +255,11 @@ impl State {
             .get_cbor(&self.allocated_sectors)
             .map_err(|e| {
                 e.downcast_default(
-                    ExitCode::USR_ILLEGAL_STATE,
+                    ExitCode::ErrIllegalState,
                     "failed to load allocated sectors bitfield",
                 )
             })?
-            .ok_or_else(|| {
-                actor_error!(USR_ILLEGAL_STATE, "allocated sectors bitfield not found")
-            })?;
+            .ok_or_else(|| actor_error!(ErrIllegalState, "allocated sectors bitfield not found"))?;
 
         if policy != CollisionPolicy::AllowCollisions {
             // NOTE: A fancy merge algorithm could extract this intersection while merging, below, saving
@@ -290,7 +267,7 @@ impl State {
             let collisions = &prior_allocation & sector_numbers;
             if !collisions.is_empty() {
                 return Err(actor_error!(
-                    USR_ILLEGAL_ARGUMENT,
+                    ErrIllegalArgument,
                     "sector numbers {:?} already allocated",
                     collisions
                 ));
@@ -298,17 +275,15 @@ impl State {
         }
         let new_allocation = &prior_allocation | sector_numbers;
         self.allocated_sectors =
-            store
-                .put_cbor(&new_allocation, Code::Blake2b256)
-                .map_err(|e| {
-                    e.downcast_default(
-                        ExitCode::USR_ILLEGAL_ARGUMENT,
-                        format!(
-                            "failed to store allocated sectors bitfield after adding {:?}",
-                            sector_numbers,
-                        ),
-                    )
-                })?;
+            store.put_cbor(&new_allocation, Code::Blake2b256).map_err(|e| {
+                e.downcast_default(
+                    ExitCode::ErrIllegalArgument,
+                    format!(
+                        "failed to store allocated sectors bitfield after adding {:?}",
+                        sector_numbers,
+                    ),
+                )
+            })?;
         Ok(())
     }
 
@@ -361,10 +336,7 @@ impl State {
 
         for &sector_number in sector_numbers {
             let info = match precommitted.get(&u64_key(sector_number)).map_err(|e| {
-                e.downcast_wrap(format!(
-                    "failed to load precommitment for {}",
-                    sector_number
-                ))
+                e.downcast_wrap(format!("failed to load precommitment for {}", sector_number))
             })? {
                 Some(info) => info.clone(),
                 None => continue,
@@ -414,10 +386,8 @@ impl State {
 
         sectors.store(new_sectors)?;
 
-        self.sectors = sectors
-            .amt
-            .flush()
-            .map_err(|e| e.downcast_wrap("failed to persist sectors"))?;
+        self.sectors =
+            sectors.amt.flush().map_err(|e| e.downcast_wrap("failed to persist sectors"))?;
 
         Ok(())
     }
@@ -654,7 +624,51 @@ impl State {
         Ok((result, !no_early_terminations))
     }
 
-    // /Returns an error if the target sector cannot be found and/or is faulty/terminated.
+    /// Returns an error if the target sector cannot be found, or some other bad state is reached.
+    /// Returns Ok(false) if the target sector is faulty, terminated, or unproven
+    /// Returns Ok(true) otherwise
+    pub fn check_sector_active<BS: Blockstore>(
+        &self,
+        policy: &Policy,
+        store: &BS,
+        deadline_idx: u64,
+        partition_idx: u64,
+        sector_number: SectorNumber,
+        require_proven: bool,
+    ) -> anyhow::Result<bool> {
+        let dls = self.load_deadlines(store)?;
+        let dl = dls.load_deadline(policy, store, deadline_idx)?;
+        let partition = dl.load_partition(store, partition_idx)?;
+
+        let exists = partition.sectors.get(sector_number);
+        if !exists {
+            return Err(actor_error!(
+                ErrNotFound;
+                "sector {} not a member of partition {}, deadline {}",
+                sector_number, partition_idx, deadline_idx
+            )
+            .into());
+        }
+
+        let faulty = partition.faults.get(sector_number);
+        if faulty {
+            return Ok(false);
+        }
+
+        let terminated = partition.terminated.get(sector_number);
+        if terminated {
+            return Ok(false);
+        }
+
+        let unproven = partition.unproven.get(sector_number);
+        if unproven && require_proven {
+            return Ok(false);
+        }
+
+        Ok(true)
+    }
+
+    /// Returns an error if the target sector cannot be found and/or is faulty/terminated.
     pub fn check_sector_health<BS: Blockstore>(
         &self,
         policy: &Policy,
@@ -669,7 +683,7 @@ impl State {
 
         if !partition.sectors.get(sector_number) {
             return Err(actor_error!(
-                USR_NOT_FOUND;
+                ErrNotFound;
                 "sector {} not a member of partition {}, deadline {}",
                 sector_number, partition_idx, deadline_idx
             )
@@ -678,7 +692,7 @@ impl State {
 
         if partition.faults.get(sector_number) {
             return Err(actor_error!(
-                USR_FORBIDDEN;
+                ErrForbidden;
                 "sector {} not a member of partition {}, deadline {}",
                 sector_number, partition_idx, deadline_idx
             )
@@ -687,7 +701,7 @@ impl State {
 
         if partition.terminated.get(sector_number) {
             return Err(actor_error!(
-                USR_NOT_FOUND;
+                ErrNotFound;
                 "sector {} not of partition {}, deadline {} is terminated",
                 sector_number, partition_idx, deadline_idx
             )
@@ -709,11 +723,9 @@ impl State {
     pub fn load_deadlines<BS: Blockstore>(&self, store: &BS) -> Result<Deadlines, ActorError> {
         store
             .get_cbor::<Deadlines>(&self.deadlines)
-            .map_err(|e| {
-                e.downcast_default(ExitCode::USR_ILLEGAL_STATE, "failed to load deadlines")
-            })?
+            .map_err(|e| e.downcast_default(ExitCode::ErrIllegalState, "failed to load deadlines"))?
             .ok_or_else(
-                || actor_error!(USR_ILLEGAL_STATE; "failed to load deadlines {}", self.deadlines),
+                || actor_error!(ErrIllegalState; "failed to load deadlines {}", self.deadlines),
             )
     }
 
@@ -735,7 +747,7 @@ impl State {
                     format!("failed to load vesting funds {}", self.vesting_funds),
                 )
             })?
-            .ok_or_else(|| actor_error!(USR_NOT_FOUND; "failed to load vesting funds {:?}", self.vesting_funds))?)
+            .ok_or_else(|| actor_error!(ErrNotFound; "failed to load vesting funds {:?}", self.vesting_funds))?)
     }
 
     /// Saves the vesting table to the store.
@@ -853,9 +865,7 @@ impl State {
 
         // * It may be possible the go implementation catches a potential panic here
         if from_vesting > self.fee_debt {
-            return Err(anyhow!(
-                "should never unlock more than the debt we need to repay"
-            ));
+            return Err(anyhow!("should never unlock more than the debt we need to repay"));
         }
         self.fee_debt -= &from_vesting;
 
@@ -873,7 +883,7 @@ impl State {
         let unlocked_balance = self.get_unlocked_balance(curr_balance)?;
         if unlocked_balance < self.fee_debt {
             return Err(actor_error!(
-                USR_INSUFFICIENT_FUNDS,
+                ErrInsufficientFunds,
                 "unlocked balance can not repay fee debt ({} < {})",
                 unlocked_balance,
                 self.fee_debt
@@ -972,19 +982,13 @@ impl State {
 
     pub fn check_balance_invariants(&self, balance: &TokenAmount) -> anyhow::Result<()> {
         if self.pre_commit_deposits.is_negative() {
-            return Err(anyhow!(
-                "pre-commit deposit is negative: {}",
-                self.pre_commit_deposits
-            ));
+            return Err(anyhow!("pre-commit deposit is negative: {}", self.pre_commit_deposits));
         }
         if self.locked_funds.is_negative() {
             return Err(anyhow!("locked funds is negative: {}", self.locked_funds));
         }
         if self.initial_pledge.is_negative() {
-            return Err(anyhow!(
-                "initial pledge is negative: {}",
-                self.initial_pledge
-            ));
+            return Err(anyhow!("initial pledge is negative: {}", self.initial_pledge));
         }
         if self.fee_debt.is_negative() {
             return Err(anyhow!("fee debt is negative: {}", self.fee_debt));
@@ -1000,10 +1004,7 @@ impl State {
 
     /// pre-commit expiry
     pub fn quant_spec_every_deadline(&self, policy: &Policy) -> QuantSpec {
-        QuantSpec {
-            unit: policy.wpost_challenge_window,
-            offset: self.proving_period_start,
-        }
+        QuantSpec { unit: policy.wpost_challenge_window, offset: self.proving_period_start }
     }
 
     pub fn add_pre_commit_clean_ups<BS: Blockstore>(
@@ -1125,7 +1126,7 @@ impl State {
         let fault_expiration = dl_info.last() + policy.fault_max_age;
 
         let (mut power_delta, detected_faulty_power) =
-            deadline.process_deadline_end(store, quant, fault_expiration)?;
+            deadline.process_deadline_end(store, quant, fault_expiration, self.sectors)?;
 
         // Capture deadline's faulty power after new faults have been detected, but before it is
         // dropped along with faulty sectors expiring this round.
@@ -1173,13 +1174,13 @@ impl State {
         for sector_no in sector_nos.iter() {
             if sector_no as u64 > MAX_SECTOR_NUMBER {
                 return Err(
-                    actor_error!(USR_ILLEGAL_ARGUMENT; "sector number greater than maximum").into(),
+                    actor_error!(ErrIllegalArgument; "sector number greater than maximum").into()
                 );
             }
             let info: &SectorPreCommitOnChainInfo =
                 precommitted
                     .get(&u64_key(sector_no as u64))?
-                    .ok_or_else(|| actor_error!(USR_NOT_FOUND, "sector {} not found", sector_no))?;
+                    .ok_or_else(|| actor_error!(ErrNotFound, "sector {} not found", sector_no))?;
             precommits.push(info.clone());
         }
         Ok(precommits)
@@ -1256,11 +1257,11 @@ impl MinerInfo {
     ) -> Result<Self, ActorError> {
         let sector_size = window_post_proof_type
             .sector_size()
-            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT, "invalid sector size: {}", e))?;
+            .map_err(|e| actor_error!(ErrIllegalArgument, "invalid sector size: {}", e))?;
 
         let window_post_partition_sectors = window_post_proof_type
             .window_post_partitions_sector()
-            .map_err(|e| actor_error!(USR_ILLEGAL_ARGUMENT, "invalid partition sectors: {}", e))?;
+            .map_err(|e| actor_error!(ErrIllegalArgument, "invalid partition sectors: {}", e))?;
 
         Ok(Self {
             owner,
